@@ -1,5 +1,6 @@
 """Various argparse actions, types, and miscellaneous extensions."""
 
+import abc
 import argparse
 import copy
 import importlib
@@ -9,6 +10,7 @@ import pkgutil
 import subprocess
 import sys
 import traceback
+import typing
 from argparse import (
     _UNRECOGNIZED_ARGS_ATTR,
     OPTIONAL,
@@ -22,16 +24,17 @@ from argparse import (
     _SubParsersAction,
 )
 from collections import Counter
-from functools import partial
+from functools import partial, wraps
+from importlib import import_module
 from itertools import chain
 from operator import attrgetter
 from textwrap import dedent
 
-import lazy_object_proxy
+from snakeoil.formatters import PlainTextFormatter
 
 from .. import klass
 from ..mappings import ImmutableDict
-from ..obj import popattr
+from ..obj import DelayedInstantiation
 from ..sequences import split_elements, split_negations
 from ..strings import pluralism
 from ..version import get_version
@@ -40,12 +43,78 @@ from ..version import get_version
 # generation, when disabled the keyword is silently discarded.
 _generate_docs = False
 
+T_main_func: typing.TypeAlias = typing.Callable[
+    [typing.Any, PlainTextFormatter, PlainTextFormatter], int
+]
 
-@klass.patch("argparse.ArgumentParser.add_subparsers")
-@klass.patch("argparse._SubParsersAction.add_parser")
-@klass.patch("argparse._ActionsContainer.add_mutually_exclusive_group")
-@klass.patch("argparse._ActionsContainer.add_argument_group")
-@klass.patch("argparse._ActionsContainer.add_argument")
+
+# BUG: This ain't desirable, find a different way.
+def _monkey_patch(target, external_decorator=None):
+    """Simplified monkeypatching via decorator.
+
+    :param target: target method to replace
+    :param external_decorator: decorator used on target method,
+        e.g. classmethod or staticmethod
+
+    Example usage (that's entirely useless):
+
+    >>> import math
+    >>> from snakeoil.klass import patch
+    >>> @patch('math.ceil')
+    >>> def ceil(orig_ceil, n):
+    ...   return math.floor(n)
+    >>> assert math.ceil(0.1) == 0
+    """
+
+    def _import_module(target):
+        components = target.split(".")
+        import_path = components.pop(0)
+        module = import_module(import_path)
+        for comp in components:
+            try:
+                module = getattr(module, comp)
+            except AttributeError:
+                import_path += f".{comp}"
+                module = import_module(import_path)
+        return module
+
+    def _get_target(target):
+        try:
+            module, attr = target.rsplit(".", 1)
+        except (TypeError, ValueError):
+            raise TypeError(f"invalid target: {target!r}")
+        module = _import_module(module)
+        return module, attr
+
+    def decorator(func):
+        # use the original function wrapper
+        func = getattr(func, "_func", func)
+
+        module, attr = _get_target(target)
+        orig_func = getattr(module, attr)
+
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            return func(orig_func, *args, **kwargs)
+
+        # save the original function wrapper
+        wrapper._func = func
+
+        if external_decorator is not None:
+            wrapper = external_decorator(wrapper)
+
+        # overwrite the original method with our wrapper
+        setattr(module, attr, wrapper)
+        return wrapper
+
+    return decorator
+
+
+@_monkey_patch("argparse.ArgumentParser.add_subparsers")
+@_monkey_patch("argparse._SubParsersAction.add_parser")
+@_monkey_patch("argparse._ActionsContainer.add_mutually_exclusive_group")
+@_monkey_patch("argparse._ActionsContainer.add_argument_group")
+@_monkey_patch("argparse._ActionsContainer.add_argument")
 def _add_argument_docs(orig_func, self, *args, **kwargs):
     """Enable docs keyword argument support for argparse arguments.
 
@@ -499,19 +568,16 @@ class _SubParser(argparse._SubParsersAction):
 
         return parser
 
-    def _lazy_parser(self, module, subcmd):
-        """Lazily-import the subcommand parser for a given module."""
-        return getattr(importlib.import_module(module), subcmd)
-
-    def add_command(self, subcmd):
+    def add_command(self, subcmd: str) -> None:
         """Register a given subcommand to be imported on demand.
 
         Note that this assumes a specific module naming and layout scheme for commands.
         """
         prog = self._prog_prefix
         module = f"{prog}.scripts.{prog}_{subcmd}"
-        func = partial(self._lazy_parser, module, subcmd)
-        self._name_parser_map[subcmd] = lazy_object_proxy.Proxy(func)
+        self._name_parser_map[subcmd] = DelayedInstantiation(
+            self.__class__, lambda: getattr(importlib.import_module(module), subcmd)
+        )
 
     def __call__(self, parser, namespace, values, option_string=None):
         """override stdlib argparse to revert subparser namespace changes
@@ -576,7 +642,9 @@ class Namespace(argparse.Namespace):
     def pop(self, key, default=klass.sentinel):
         """Remove and return an object from the namespace if it exists."""
         try:
-            return popattr(self, key)
+            val = getattr(self, key)
+            delattr(self, key)
+            return val
         except AttributeError:
             if default is not klass.sentinel:
                 return default
@@ -1022,7 +1090,7 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
         # subparsers action object from calling add_subparsers()
         self.__subparsers = None
         # function to execute for this parser
-        self.__main_func = None
+        self.__main_func: T_main_func | None = None
         # pre-parse functions to execute for this parser
         self.__pre_parse = []
         # early parse functions to execute for this parser
@@ -1247,7 +1315,15 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
                 namespace, args = functor(parser, namespace, args)
 
             # parse the arguments and exit if there are any errors
-            namespace, args = self._parse_known_args(args, namespace)
+            # Python 3.12.8 introduced obligatory intermixed arg.  The same
+            # commit adds _parse_known_args2 function, so use that to determine
+            # if we need to pass that.
+            if hasattr(self, "_parse_known_args2"):
+                namespace, args = self._parse_known_args(
+                    args, namespace, intermixed=False
+                )
+            else:
+                namespace, args = self._parse_known_args(args, namespace)
             if hasattr(namespace, _UNRECOGNIZED_ARGS_ATTR):
                 args.extend(getattr(namespace, _UNRECOGNIZED_ARGS_ATTR))
                 delattr(namespace, _UNRECOGNIZED_ARGS_ATTR)
@@ -1327,7 +1403,7 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
             traceback.print_exc()
         self.exit(status, f"{self.prog}: error: {message}\n")
 
-    def bind_main_func(self, functor):
+    def bind_main_func(self, functor: T_main_func) -> T_main_func:
         """Decorator to set a main function for the parser."""
         self.set_defaults(main_func=functor)
         self.__main_func = functor
@@ -1401,12 +1477,12 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
         return functor
 
 
-class ArgparseCommand:
+class ArgparseCommand(abc.ABC):
     def bind_to_parser(self, parser):
         parser.bind_main_func(self)
 
-    def __call__(self, namespace, out, err):
-        raise NotImplementedError(self, "__call__")
+    @abc.abstractmethod
+    def __call__(self, namespace, out, err): ...
 
 
 class FileType(argparse.FileType):
