@@ -1,22 +1,28 @@
 """Generic support for running commandline tools."""
 
-from functools import partial
-import logging
 import io
+import logging
 import os
-from signal import signal, SIGPIPE, SIG_DFL, SIGINT
 import sys
 import traceback
+from contextlib import nullcontext
+from functools import partial
+from signal import SIG_DFL, SIGINT, SIGPIPE, signal
 
-from .exceptions import ExitException, find_user_exception
 from .. import formatters
-from ..contexts import nullcontext
 from ..log import suppress_logging
+from .exceptions import ExitException, find_user_exception
 
 
 class Tool:
     """Abstraction for commandline tools."""
 
+    # TODO: remove args once all downstreams have been fixed to pass *args/**kwargs down
+    __slots__ = ("out", "err", "parser", "options", "_outfile", "_errfile", "args")
+
+    out: formatters.Formatter
+    err: formatters.Formatter
+
     def __init__(self, parser, outfile=None, errfile=None):
         """Initialize the utility to run.
 
@@ -36,14 +42,14 @@ class Tool:
             if not sys.stdout.isatty() and sys.stdout == sys.__stdout__:
                 # if redirecting/piping stdout use line buffering, skip if
                 # stdout has been set to some non-standard object
-                outfile = os.fdopen(sys.stdout.fileno(), 'w', 1)
+                outfile = os.fdopen(sys.stdout.fileno(), "w", 1)
             else:
                 outfile = sys.stdout
         if errfile is None:
             errfile = sys.stderr
 
         out_fd = err_fd = None
-        if hasattr(outfile, 'fileno') and hasattr(errfile, 'fileno'):
+        if hasattr(outfile, "fileno") and hasattr(errfile, "fileno"):
             # annoyingly, fileno can exist but through unsupport
             try:
                 out_fd, err_fd = outfile.fileno(), errfile.fileno()
@@ -52,9 +58,11 @@ class Tool:
 
         if out_fd is not None and err_fd is not None:
             out_stat, err_stat = os.fstat(out_fd), os.fstat(err_fd)
-            if out_stat.st_dev == err_stat.st_dev \
-                    and out_stat.st_ino == err_stat.st_ino and \
-                    not errfile.isatty():
+            if (
+                out_stat.st_dev == err_stat.st_dev
+                and out_stat.st_ino == err_stat.st_ino
+                and not errfile.isatty()
+            ):
                 # they're the same underlying fd.  thus
                 # point the handles at the same so we don't
                 # get intermixed buffering issues.
@@ -64,7 +72,6 @@ class Tool:
         self._errfile = errfile
         self.out = self.parser.out = formatters.PlainTextFormatter(outfile)
         self.err = self.parser.err = formatters.PlainTextFormatter(errfile)
-        self.out.verbosity = self.err.verbosity = getattr(self.parser, 'verbosity', 0)
 
     def __call__(self, args=None):
         """Run the utility.
@@ -98,20 +105,19 @@ class Tool:
         try:
             self.pre_parse(args, namespace)
             options = self.parser.parse_args(args=args, namespace=namespace)
-            main_func = options.pop('main_func', None)
+            main_func = options.pop("main_func", None)
             if main_func is None:
                 raise RuntimeError("argparser missing main method")
 
             # reconfigure formatters for colored output if enabled
-            if getattr(options, 'color', True):
+            if getattr(options, "color", True):
                 formatter_factory = partial(
-                    formatters.get_formatter, force_color=getattr(options, 'color', False))
+                    formatters.get_formatter,
+                    force_color=getattr(options, "color", False),
+                )
                 self.out = formatter_factory(self._outfile)
                 self.err = formatter_factory(self._errfile)
 
-            # reconfigure formatters with properly parsed output verbosity
-            self.out.verbosity = self.err.verbosity = getattr(options, 'verbosity', 0)
-
             if logging.root.handlers:
                 # Remove the default handler.
                 logging.root.handlers.pop(0)
@@ -138,22 +144,24 @@ class Tool:
         exc = find_user_exception(e)
         if exc is not None:
             # allow exception attribute to override user verbosity level
-            if getattr(exc, '_verbosity', None) is not None:
+            if getattr(exc, "_verbosity", None) is not None:
                 verbosity = exc._verbosity
             else:
-                verbosity = getattr(self.parser, 'verbosity', 0)
+                verbosity = getattr(self.parser, "verbosity", 0)
             # output verbose error message if it exists
             if verbosity > 0:
-                msg = exc.msg(verbosity).strip('\n')
+                msg = exc.msg(verbosity).strip("\n")
                 if msg:
                     self.err.write(msg)
                     raise SystemExit
             self.parser.error(exc)
         raise
 
-    def main(self):
+    def main(self, args=None):
         """Execute the main script function."""
-        exitstatus = -10
+        exitstatus: int = -10
+
+        args = self.args if args is None else args
 
         # ignore broken pipes
         signal(SIGPIPE, SIG_DFL)
@@ -166,15 +174,17 @@ class Tool:
 
         try:
             with suppress_warnings:
-                self.options, func = self.parse_args(args=self.args, namespace=self.options)
+                self.options, func = self.parse_args(
+                    args=self.args, namespace=self.options
+                )
                 exitstatus = func(self.options, self.out, self.err)
         except SystemExit as e:
             # handle argparse or other third party modules using sys.exit internally
-            exitstatus = e.code
+            exitstatus = e.code  # pyright: ignore[reportAssignmentType]
         except KeyboardInterrupt:
-            self._errfile.write('keyboard interrupted- exiting')
+            self._errfile.write("keyboard interrupted- exiting")
             if self.parser.debug:
-                self._errfile.write('\n')
+                self._errfile.write("\n")
                 traceback.print_exc()
             signal(SIGINT, SIG_DFL)
             os.killpg(os.getpgid(0), SIGINT)
@@ -187,9 +197,9 @@ class Tool:
         if self.options is not None:
             # set terminal title on exit
             if exitstatus:
-                self.out.title(f'{self.options.prog} failed')
+                self.out.title(f"{self.options.prog} failed")
             else:
-                self.out.title(f'{self.options.prog} succeeded')
+                self.out.title(f"{self.options.prog} succeeded")
 
         return exitstatus
 
@@ -197,27 +207,38 @@ class Tool:
 class FormattingHandler(logging.Handler):
     """Logging handler printing through a formatter."""
 
-    def __init__(self, formatter):
+    __slots__ = ("out",)
+
+    def __init__(self, formatter: formatters.Formatter):
         logging.Handler.__init__(self)
         # "formatter" clashes with a Handler attribute.
         self.out = formatter
 
     def emit(self, record):
         if record.levelno >= logging.ERROR:
-            color = 'red'
+            color = "red"
         elif record.levelno >= logging.WARNING:
-            color = 'yellow'
+            color = "yellow"
         else:
-            color = 'cyan'
-        first_prefix = (self.out.fg(color), self.out.bold, record.levelname,
-                        self.out.reset, ' ', record.name, ': ')
-        later_prefix = (len(record.levelname) + len(record.name)) * ' ' + ' : '
+            color = "cyan"
+        first_prefix = (
+            self.out.fg(color),
+            self.out.bold,
+            record.levelname,
+            self.out.reset,
+            " ",
+            record.name,
+            ": ",
+        )
+        later_prefix = (len(record.levelname) + len(record.name)) * " " + " : "
         self.out.first_prefix.extend(first_prefix)
         self.out.later_prefix.append(later_prefix)
         try:
-            for line in self.format(record).split('\n'):
+            for line in self.format(record).split("\n"):
                 self.out.write(line, wrap=True)
+        except Exception:
+            self.handleError(record)
         finally:
             self.out.later_prefix.pop()
-            for i in range(len(first_prefix)):
+            for _ in range(len(first_prefix)):
                 self.out.first_prefix.pop()
