@@ -15,6 +15,8 @@ Usage examples:
 >>>     print(f"x={solution['x']}, y={solution['y']}, z={solution['z']}")
 """
 
+__all__ = ("Constraint", "Problem")
+
 from collections import defaultdict
 from typing import Any, Iterable, Protocol
 
@@ -32,11 +34,12 @@ class Constraint(Protocol):
         :return: ``True`` if the assignment is satisfied.
     """
 
-    def __call__(self, **kwargs: Any) -> bool:
-        raise NotImplementedError("Constraint", "__call__")
+    def __call__(self, **kwargs: Any) -> bool: ...
 
 
 class _Domain(list):
+    __slots__ = ("_hidden", "_states")
+
     def __init__(self, items: Iterable[Any]):
         super().__init__(items)
         self._hidden = []
@@ -77,12 +80,14 @@ class Problem:
         single value from it's domain.
     """
 
+    __slots__ = ("variables", "constraints", "vconstraints")
+
     def __init__(self):
         self.variables: dict[str, _Domain] = {}
         self.constraints: list[tuple[Constraint, frozenset[str]]] = []
-        self.vconstraints: dict[
-            str, list[tuple[Constraint, frozenset[str]]]
-        ] = defaultdict(list)
+        self.vconstraints: dict[str, list[tuple[Constraint, frozenset[str]]]] = (
+            defaultdict(list)
+        )
 
     def add_variable(self, domain: Iterable[Any], *variables: str):
         """Add variables to the problem, which use the specified domain.
@@ -98,9 +103,9 @@ class Problem:
             from each domain.
         """
         for variable in variables:
-            assert (
-                variable not in self.variables
-            ), f"variable {variable!r} was already added"
+            assert variable not in self.variables, (
+                f"variable {variable!r} was already added"
+            )
             self.variables[variable] = _Domain(domain)
 
     def add_constraint(self, constraint: Constraint, variables: frozenset[str]):
