@@ -1,5 +1,6 @@
 """Classes wrapping a file-like object to do fancy output on it."""
 
+import abc
 import errno
 import io
 import locale
@@ -7,7 +8,7 @@ import os
 import typing
 from functools import partial
 
-from .klass import GetAttrProxy, steal_docs
+from .klass import GetAttrProxy, copy_docs
 from .mappings import defaultdictkey
 
 __all__ = (
@@ -32,7 +33,7 @@ class StreamClosed(KeyboardInterrupt):
 # pylint: disable=C0103
 
 
-class Formatter:
+class Formatter(abc.ABC):
     """Abstract formatter base class.
 
     The types of most of the instance attributes is undefined (depends
@@ -46,10 +47,12 @@ class Formatter:
         (defaults to on).
     """
 
-    def __init__(self):
+    def __init__(self, stream: typing.IO):
         self.autoline = True
         self.wrap = False
+        self.stream = stream
 
+    @abc.abstractmethod
     def write(
         self,
         *args: typing.Union[None, str, typing.Callable[["Formatter"], None]],
@@ -146,7 +149,7 @@ class PlainTextFormatter(Formatter):
         :param width: maximum line width (defaults to 79).
         :param encoding: encoding unicode strings are converted to.
         """
-        super().__init__()
+        super().__init__(stream)
         # We used to require a TextIOWrapper on py3. We still accept
         # one, guess the encoding from it and grab its underlying
         # bytestream.
@@ -201,7 +204,6 @@ class PlainTextFormatter(Formatter):
             # but it is completely arbitrary.
             self._pos = self.width - 10
 
-    @steal_docs(Formatter)
     def write(self, *args, **kwargs):
         wrap = kwargs.get("wrap", self.wrap)
         autoline = kwargs.get("autoline", self.autoline)
@@ -211,8 +213,7 @@ class PlainTextFormatter(Formatter):
         if prefixes is not None:
             if first_prefixes is not None or later_prefixes is not None:
                 raise TypeError(
-                    "do not pass first_prefixes or later_prefixes "
-                    "if prefixes is passed"
+                    "do not pass first_prefixes or later_prefixes if prefixes is passed"
                 )
             first_prefixes = later_prefixes = prefixes
         prefix = kwargs.get("prefix")
@@ -407,7 +408,6 @@ else:
             raise AttributeError(f"{self.__class__.__name__} instances are immutable")
 
     class TerminfoMode(TerminfoCode):
-
         __doc__ = TerminfoCode.__doc__
         __slots__ = ()
 
@@ -416,7 +416,6 @@ else:
             formatter.stream.write(self.value)
 
     class TerminfoReset(TerminfoCode):
-
         __doc__ = TerminfoCode.__doc__
         __slots__ = ()
 
@@ -490,15 +489,14 @@ else:
             self._fg_cache = defaultdictkey(partial(TerminfoColor, 0))
             self._bg_cache = defaultdictkey(partial(TerminfoColor, 1))
 
-        @steal_docs(Formatter)
+        @copy_docs(Formatter.fg)
         def fg(self, color=None):
             return self._fg_cache[color]
 
-        @steal_docs(Formatter)
+        @copy_docs(Formatter.bg)
         def bg(self, color=None):
             return self._bg_cache[color]
 
-        @steal_docs(Formatter)
         def write(self, *args, **kwargs):
             super().write(*args, **kwargs)
             try:
@@ -512,8 +510,8 @@ else:
                     raise StreamClosed(e)
                 raise
 
-        @steal_docs(Formatter)
-        def title(self, string):
+        def title(self, title: str):  # pyright: ignore[reportIncompatibleMethodOverride]
+            """ "Set the title"""
             # I want to use curses.tigetflag('hs') here but at least
             # the screen-s entry defines a tsl and fsl string but does
             # not set the hs flag. So just check for the ability to
@@ -522,7 +520,7 @@ else:
             tsl = curses.tigetstr("tsl")
             fsl = curses.tigetstr("fsl")
             if tsl and fsl:
-                self.stream.write(tsl + string.encode(self.encoding, "replace") + fsl)
+                self.stream.write(tsl + title.encode(self.encoding, "replace") + fsl)
                 self.stream.flush()
 
 
