@@ -19,12 +19,14 @@ __all__ = (
 import operator
 from collections import defaultdict
 from collections.abc import Mapping, MutableSet, Set
-from functools import partial
+from functools import partial, wraps
 from itertools import chain, filterfalse, islice
+from typing import Any
 
-from .klass import contains, get, sentinel, steal_docs
+from .klass import contains, copy_docs, get, get_attrs_of, sentinel
 
 
+@copy_docs(dict)
 class DictMixin:
     """
     new style class replacement for :py:func:`UserDict.DictMixin`
@@ -57,28 +59,22 @@ class DictMixin:
         if kwargs:
             self.update(kwargs.items())
 
-    @steal_docs(dict)
     def __iter__(self):
         return self.keys()
 
-    @steal_docs(dict)
     def __str__(self):
         return str(dict(self.items()))
 
-    @steal_docs(dict)
     def items(self):
         for k in self:
             yield k, self[k]
 
-    @steal_docs(dict)
     def keys(self):
         raise NotImplementedError(self, "keys")
 
-    @steal_docs(dict)
     def values(self):
         return map(self.__getitem__, self)
 
-    @steal_docs(dict)
     def update(self, iterable):
         for k, v in iterable:
             self[k] = v
@@ -86,7 +82,6 @@ class DictMixin:
     get = get
     __contains__ = contains
 
-    @steal_docs(dict)
     def __eq__(self, other):
         if len(self) != len(other):
             return False
@@ -97,11 +92,9 @@ class DictMixin:
                 return False
         return True
 
-    @steal_docs(dict)
     def __ne__(self, other):
         return not self.__eq__(other)
 
-    @steal_docs(dict)
     def pop(self, key, default=sentinel):
         if not self.__externally_mutable__:
             raise AttributeError(self, "pop")
@@ -114,7 +107,6 @@ class DictMixin:
             raise
         return val
 
-    @steal_docs(dict)
     def setdefault(self, key, default=None):
         if not self.__externally_mutable__:
             raise AttributeError(self, "setdefault")
@@ -136,7 +128,6 @@ class DictMixin:
             raise AttributeError(self, "__delitem__")
         raise NotImplementedError(self, "__delitem__")
 
-    @steal_docs(dict)
     def clear(self):
         if not self.__externally_mutable__:
             raise AttributeError(self, "clear")
@@ -158,7 +149,6 @@ class DictMixin:
             return True
         return False
 
-    @steal_docs(dict)
     def popitem(self):
         if not self.__externally_mutable__:
             raise AttributeError(self, "popitem")
@@ -298,7 +288,7 @@ class ProtectedDict(DictMixin):
         raise KeyError(key)
 
     def keys(self):
-        for k in self.new.keys():
+        for k in self.new:
             yield k
         for k in self.orig.keys():
             if k not in self.blacklist and k not in self.new:
@@ -314,20 +304,22 @@ class ImmutableDict(Mapping):
     Because this is immutable, it's hashable.
     """
 
+    __slots__ = ("_dict", "__weakref__")
+
     def __init__(self, data=None):
         if isinstance(data, ImmutableDict):
             mapping = data._dict
         elif isinstance(data, Mapping):
             mapping = data
         elif isinstance(data, DictMixin):
-            mapping = {k: v for k, v in data.items()}
+            mapping = dict(data.items())
         elif data is None:
             mapping = {}
         else:
             try:
-                mapping = {k: v for k, v in data}
-            except TypeError as e:
-                raise TypeError(f"unsupported data format: {e}")
+                mapping = dict(data)
+            except TypeError as exc:
+                raise TypeError(f"unsupported data format: {exc}")
         object.__setattr__(self, "_dict", mapping)
 
     def __getitem__(self, key):
@@ -359,11 +351,13 @@ class ImmutableDict(Mapping):
 class OrderedFrozenSet(Set):
     """Ordered, immutable set using guaranteed insertion order dicts in py3.6 onwards."""
 
+    __slots__ = ("_dict",)
+
     def __init__(self, iterable=()):
         try:
             self._dict = ImmutableDict({x: None for x in iterable})
-        except TypeError as e:
-            raise TypeError("not iterable") from e
+        except TypeError as exc:
+            raise TypeError("not iterable") from exc
 
     def __contains__(self, key):
         return key in self._dict
@@ -416,11 +410,13 @@ class OrderedFrozenSet(Set):
 class OrderedSet(OrderedFrozenSet, MutableSet):
     """Ordered, mutable set using guaranteed insertion order dicts in py3.6 onwards."""
 
+    __slots__ = ()
+
     def __init__(self, iterable=()):
         try:
             self._dict = {x: None for x in iterable}
-        except TypeError as e:
-            raise TypeError("not iterable") from e
+        except TypeError as exc:
+            raise TypeError("not iterable") from exc
 
     def add(self, value):
         self._dict[value] = None
@@ -444,6 +440,7 @@ class OrderedSet(OrderedFrozenSet, MutableSet):
         raise TypeError(f"unhashable type: {self.__class__.__name__!r}")
 
 
+@copy_docs(dict)
 class IndeterminantDict:
     """A wrapped dict with constant defaults, and a function for other keys.
 
@@ -501,6 +498,8 @@ class IndeterminantDict:
 class StackedDict(DictMixin):
     """An unmodifiable dict that makes multiple dicts appear as one"""
 
+    __slots__ = ("_dicts",)
+
     def __init__(self, *dicts):
         self._dicts = dicts
 
@@ -525,7 +524,7 @@ class StackedDict(DictMixin):
     def __setitem__(self, *a):
         raise TypeError("unmodifiable")
 
-    __delitem__ = clear = __setitem__
+    __delitem__ = clear = __setitem__  # pyright: ignore[reportAssignmentType]
 
 
 class PreservingFoldingDict(DictMixin):
@@ -538,6 +537,8 @@ class PreservingFoldingDict(DictMixin):
     This version returns the original 'unfolded' key.
     """
 
+    __slots__ = ("_dict", "_folder")
+
     def __init__(self, folder, sourcedict=None):
         self._folder = folder
         # dict mapping folded keys to (original key, value)
@@ -602,6 +603,8 @@ class NonPreservingFoldingDict(DictMixin):
     This version returns the 'folded' key.
     """
 
+    __slots__ = ("_dict", "_folder")
+
     def __init__(self, folder, sourcedict=None):
         self._folder = folder
         # dict mapping folded keys to values.
@@ -617,6 +620,7 @@ class NonPreservingFoldingDict(DictMixin):
 
     def __setitem__(self, key, value):
         self._dict[self._folder(key)] = value
+        return value
 
     def __delitem__(self, key):
         del self._dict[self._folder(key)]
@@ -654,21 +658,19 @@ class defaultdictkey(defaultdict):
         # that a default_factory is required
         defaultdict.__init__(self, default_factory)
 
-    @steal_docs(defaultdict)
     def __missing__(self, key):
         obj = self[key] = self.default_factory(key)
         return obj
 
 
 def _KeyError_to_Attr(functor):
+    @wraps(functor)
     def inner(self, *args):
         try:
             return functor(self, *args)
         except KeyError:
             raise AttributeError(args[0])
 
-    inner.__name__ = functor.__name__
-    inner.__doc__ = functor.__doc__
     return inner
 
 
@@ -732,29 +734,31 @@ class ProxiedAttrs(DictMixin):
 
     __slots__ = ("__target__",)
 
-    def __init__(self, target):
+    def __init__(self, target: Mapping[Any, Any]) -> None:
         self.__target__ = target
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: Any) -> Any:
         try:
             return getattr(self.__target__, key)
         except AttributeError:
             raise KeyError(key)
 
-    def __setitem__(self, key, value):
+    # While it seems like value: TypeVar("T") -> T is correct,
+    # the underlying __setattr__ may mutate/return something else.
+    def __setitem__(self, key: Any, value: Any) -> Any:
         try:
             return setattr(self.__target__, key, value)
         except AttributeError:
             raise KeyError(key)
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: Any):
         try:
             return delattr(self.__target__, key)
         except AttributeError:
             raise KeyError(key)
 
     def keys(self):
-        return iter(dir(self.__target__))
+        return map(operator.itemgetter(0), get_attrs_of(self.__target__))
 
 
 class _SlottedDict(DictMixin):
@@ -875,7 +879,9 @@ class _SlottedDict(DictMixin):
 
 
 def make_SlottedDict_kls(keys):
-    """Create a space efficient mapping class with a limited set of keys."""
+    """
+    Create a space efficient mapping class with a limited set of keys.
+    """
     new_keys = tuple(sorted(keys))
     cls_name = f"SlottedDict_{hash(new_keys)}"
     o = globals().get(cls_name, None)
