@@ -3,7 +3,6 @@ subprocess related functionality
 """
 
 __all__ = [
-    "cleanup_pids",
     "spawn",
     "spawn_sandbox",
     "spawn_bash",
@@ -19,7 +18,6 @@ import sys
 from typing import Iterable, Optional, Sequence, Union
 
 from ..mappings import ProtectedDict
-from ..osutils import access
 from . import find_binary
 
 BASH_BINARY = find_binary("bash", fallback="/bin/bash")
@@ -137,7 +135,7 @@ atexit.register(run_exitfuncs)
 spawned_pids = []
 
 
-def cleanup_pids(pids: Iterable[int] = None):
+def cleanup_pids(pids: Iterable[int] | None = None):
     """reap list of pids if specified, else all children"""
 
     if pids is None:
@@ -176,7 +174,6 @@ def spawn(
     cwd: Optional[str] = None,
     pgid: Optional[int] = None,
 ):
-
     """wrapper around execve
 
     :type mycommand: list or string
@@ -237,7 +234,6 @@ def spawn(
     try:
         # Otherwise we clean them up.
         while mypids:
-
             # Pull the last reader in the pipe chain. If all processes
             # in the pipe are well behaved, it will die when the process
             # it is reading from dies.
@@ -380,7 +376,6 @@ def spawn_get_output(
     split_lines: bool = True,
     **kwds,
 ):
-
     """Call spawn, collecting the output to fd's specified in collect_fds list.
 
     :param spawn_type: the passed in function to call- typically :func:`spawn_bash`
@@ -471,7 +466,7 @@ def is_sandbox_capable(force: bool = False):
     if "SANDBOX_ACTIVE" in os.environ:
         # we can not spawn a sandbox inside another one
         res = False
-    elif not (os.path.isfile(SANDBOX_BINARY) and access(SANDBOX_BINARY, os.X_OK)):
+    elif not (os.path.isfile(SANDBOX_BINARY) and os.access(SANDBOX_BINARY, os.X_OK)):
         res = False
     else:
         try:
