@@ -1,12 +1,16 @@
 import errno
-import inspect
 import os
 import stat
 import sys
 
-from ..compatibility import IGNORED_EXCEPTIONS
+from snakeoil._internals import deprecated
+from snakeoil.compatibility import IGNORED_EXCEPTIONS
 
 
+@deprecated(
+    "Use snakeoil.python_namespaces.submodules_of, or derive from snakeoil.code_quality.NamespaceWalker for tests",
+    removal_in=(0, 12, 0),
+)
 class PythonNamespaceWalker:
     ignore_all_import_failures = False
 
@@ -20,7 +24,6 @@ class PythonNamespaceWalker:
     module_blacklist = frozenset(
         {
             "snakeoil.cli.arghparse",
-            "snakeoil.pickling",
         }
     )
 
@@ -39,10 +42,15 @@ class PythonNamespaceWalker:
         if ignore_failed_imports is None:
             ignore_failed_imports = self.ignore_all_import_failures
         if namespace is None:
-            mangle = lambda x: x
+
+            def mangle(x):  # pyright: ignore[reportRedeclaration]
+                return x
         else:
             orig_namespace = namespace
-            mangle = lambda x: f"{orig_namespace}.{x}"
+
+            def mangle(x):
+                return f"{orig_namespace}.{x}"
+
         if blacklist_func is None:
             blacklist_func = self._default_module_blacklister
         for mod_name in feed:
@@ -64,15 +72,15 @@ class PythonNamespaceWalker:
             # Shouldn't be possible, but make sure we avoid this if it manages
             # to occur.
             return
-        l = os.listdir(location)
-        if not self.valid_inits.intersection(l):
+        dirents = os.listdir(location)
+        if not self.valid_inits.intersection(dirents):
             if valid_namespace:
                 return
         else:
             yield None
 
         stats: list[tuple[str, int]] = []
-        for x in l:
+        for x in dirents:
             try:
                 stats.append((x, os.stat(os.path.join(location, x)).st_mode))
             except OSError as exc:
@@ -130,86 +138,3 @@ class PythonNamespaceWalker:
             except Exception as e:
                 raise AssertionError(f"failed importing target {namespace}; error {e}")
         return obj
-
-
-class TargetedNamespaceWalker(PythonNamespaceWalker):
-    target_namespace = None
-
-    def load_namespaces(self, namespace=None):
-        if namespace is None:
-            namespace = self.target_namespace
-        for _mod in self.walk_namespace(namespace):
-            pass
-
-
-class _classWalker:
-    cls_blacklist = frozenset()
-
-    def is_blacklisted(self, cls):
-        return cls.__name__ in self.cls_blacklist
-
-    def test_object_derivatives(self, *args, **kwds):
-        # first load all namespaces...
-        self.load_namespaces()
-
-        # next walk all derivatives of object
-        for cls in self.walk_derivatives(object, *args, **kwds):
-            if not self._should_ignore(cls):
-                self.run_check(cls)
-
-    def iter_builtin_targets(self):
-        for attr in dir(__builtins__):
-            obj = getattr(__builtins__, attr)
-            if not inspect.isclass(obj):
-                continue
-            yield obj
-
-    def test_builtin_derivatives(self, *args, **kwds):
-        self.load_namespaces()
-        for obj in self.iter_builtin_targets():
-            for cls in self.walk_derivatives(obj, *args, **kwds):
-                if not self._should_ignore(cls):
-                    self.run_check(cls)
-
-    def walk_derivatives(self, obj):
-        raise NotImplementedError(self.__class__, "walk_derivatives")
-
-    def run_check(self, cls):
-        raise NotImplementedError
-
-
-class SubclassWalker(_classWalker):
-    def walk_derivatives(self, cls, seen=None):
-        if len(inspect.signature(cls.__subclasses__).parameters) != 0:
-            return
-        if seen is None:
-            seen = set()
-        pos = 0
-        for pos, subcls in enumerate(cls.__subclasses__()):
-            if subcls in seen:
-                continue
-            seen.add(subcls)
-            if self.is_blacklisted(subcls):
-                continue
-            for grand_daddy in self.walk_derivatives(subcls, seen):
-                yield grand_daddy
-        if pos == 0:
-            yield cls
-
-
-class KlassWalker(_classWalker):
-    def walk_derivatives(self, cls, seen=None):
-        if len(inspect.signature(cls.__subclasses__).parameters) != 0:
-            return
-
-        if seen is None:
-            seen = set()
-        elif cls not in seen:
-            seen.add(cls)
-            yield cls
-
-        for subcls in cls.__subclasses__():
-            if subcls in seen:
-                continue
-            for node in self.walk_derivatives(subcls, seen=seen):
-                yield node
