@@ -1,5 +1,7 @@
-import pytest
 import gc
+
+import pytest
+
 from snakeoil.caching import WeakInstMeta
 
 
@@ -116,10 +118,9 @@ class TestWeakInstMeta:
 
         assert weak_inst([]) is not weak_inst([])
         assert weak_inst.counter == 2
-        for x in (TypeError, NotImplementedError):
-            assert weak_inst(RaisingHashForTestUncachable(x)) is not weak_inst(
-                RaisingHashForTestUncachable(x)
-            )
+        assert weak_inst(RaisingHashForTestUncachable(TypeError)) is not weak_inst(
+            RaisingHashForTestUncachable(TypeError)
+        )
 
     @pytest.mark.filterwarnings("error::UserWarning")
     def test_uncachable_warning_msg(self):
@@ -131,9 +132,8 @@ class TestWeakInstMeta:
             def __hash__(self):
                 raise self.error
 
-        for x in (TypeError, NotImplementedError):
-            with pytest.raises(UserWarning):
-                weak_inst(RaisingHashForTestUncachableWarnings(x))
+        with pytest.raises(UserWarning):
+            weak_inst(RaisingHashForTestUncachableWarnings(TypeError))
 
     def test_hash_collision(self):
         class BrokenHash:
@@ -169,3 +169,23 @@ class TestWeakInstMeta:
         gc.collect()
         o = weak_inst(unique)
         assert weak_inst.counter == 2
+
+    def test_function_metadata(self):
+        def f(
+            self, x: str, y: int = 1, *a: tuple[str, ...], **kw: int
+        ) -> dict[str, int]:
+            "blah blah blah blah"
+            return {}
+
+        class c(metaclass=WeakInstMeta):
+            __inst_caching__ = True
+            __init__ = f  # type: ignore
+
+        new_call = c.__class__.__call__
+        # ensure it's not mutating the reference functools passes.
+        assert new_call.__annotations__ is not f.__annotations__
+        assert new_call.__annotations__["disable_inst_caching"] == bool
+        a = new_call.__annotations__.copy()
+        a.pop("disable_inst_caching")
+        assert a == f.__annotations__
+        assert c.__init__.__doc__ == f.__doc__
