@@ -4,11 +4,15 @@ import platform
 import random
 import socket
 import sys
+from contextlib import chdir
 
 import pytest
-from snakeoil.contexts import Namespace, SplitExec, chdir, syspath
+
+from snakeoil._internals import deprecated
+from snakeoil.contexts import Namespace, SplitExec, syspath
 
 
+@deprecated.suppress_deprecations()
 def test_chdir(tmpdir):
     orig_cwd = os.getcwd()
 
@@ -44,8 +48,8 @@ def test_syspath(tmpdir):
             assert mangled_syspath == tuple(sys.path)
 
 
-@pytest.mark.skip(
-    reason="this currently breaks on github ci, https://github.com/pkgcore/snakeoil/issues/68"
+@pytest.mark.xfail(
+    reason="this currently is broken: https://github.com/pkgcore/snakeoil/issues/68 is the GH side first incidence of it"
 )
 class TestSplitExec:
     def test_context_process(self):
